@@ -30,19 +30,10 @@ Name Authority Cooperative. The rules are described in detail at: http://www.loc
 
 =head1 INSTALLATION
 
-To install this module via Module::Build:
-
-	perl Build.PL
-	./Build         # or `perl Build`
-	./Build test    # or `perl Build test`
-	./Build install # or `perl Build install`
-
-To install this module via ExtUtils::MakeMaker:
-
-	perl Makefile.PL
-	make
-	make test
-	make install
+    perl Makefile.PL
+    make
+    make test
+    make install
 
 =cut
 
@@ -53,7 +44,7 @@ use warnings;
 
 use Text::Unidecode;
 
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 
 our @EXPORT_OK = qw( naco_normalize );
 
@@ -179,19 +170,15 @@ sub normalize {
 
 =head1 AUTHOR
 
-=over 4 
-
-=item * Brian Cassidy E<lt>bricas@cpan.orgE<gt>
-
-=back
+Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Brian Cassidy
+Copyright 2007 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =cut
 
-1;
\ No newline at end of file
+1;
